<template>
  <div class="app-container">
    <div class="search">
      <el-form :model="queryParams" ref="queryParams" size="small" :inline="true">
        <el-row>
          <el-form-item label="产品名称" prop="name">
            <el-input v-model="queryParams.name" clearable placeholder="请输入" size="small"
              @keyup.enter.native="refreshTable"></el-input>
          </el-form-item>
          <el-form-item label="SP号" prop="spNum">
            <el-input v-model="queryParams.spNum" clearable placeholder="请输入" size="small"
              @keyup.enter.native="refreshTable">
            </el-input>
          </el-form-item>
          <el-form-item>
            <el-button size="mini" type="primary" @click="refreshTable()">查 询</el-button>
            <el-button size="mini" @click="refresh()">重 置</el-button>
          </el-form-item>
        </el-row>
      </el-form>
      <div>
        <el-button size="mini" type="primary">获取订单</el-button>
        <!-- <el-button size="mini" type="primary" @click="openAdd('新增')">新增</el-button> -->
      </div>
    </div>
    <lims-table :tableData="tableData" :column="column" :tableLoading="tableLoading" :height="'calc(100vh - 240px)'"
      :page="page" @pagination="pagination"></lims-table>
    <!-- 新增/编辑 -->
    <el-dialog :title="title" :visible.sync="addDia" width="500px">
      <el-form :model="addForm" v-if="addDia" ref="addForm" :rules="addRules" label-position="right"
        label-width="120px">
        <el-form-item label="产品" prop="name">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.name" disabled></el-input>
        </el-form-item>
        <el-form-item label="来料数量" prop="num">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.num" disabled>
          </el-input>
        </el-form-item>
        <el-form-item label="供货厂家" prop="supplier">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.supplier" disabled>
          </el-input>
        </el-form-item>
        <el-form-item label="订单号" prop="orderNum">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.orderNum" disabled>
          </el-input>
        </el-form-item>
        <el-form-item label="SP号" prop="spNum">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.spNum" disabled>
          </el-input>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input size="small" placeholder="请输入" type="textarea" :rows="2" clearable v-model="addForm.remark"
            disabled>
          </el-input>
        </el-form-item>
        <el-form-item label="外观" prop="inspectionItems">
          <el-input size="small" placeholder="请输入" clearable v-model="addForm.inspectionItems"
            :disabled="title != '检验'">
          </el-input>
        </el-form-item>
        <el-form-item label="检测结果" prop="result">
          <el-select v-model="addForm.result" placeholder="请选择" :disabled="title != '检验'">
            <el-option label="合格" value="合格">
            </el-option>
            <el-option label="不合格" value="不合格">
            </el-option>
            <el-option label="不判断" value="不判断">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="测试文件" prop="file">
          <el-upload action="#" :auto-upload="false" :multiple="false" v-if="title == '检验'"
            accept='.jpg,.jpeg,.png,.gif,.doc,.docx,.xls,.xlsx,.pdf,' :on-change="handleChangeUpload">
            <el-button size="mini" type="primary">上传附件</el-button>
          </el-upload>
          <a @click="handleDown(addForm)" v-else style="color: #3a7bfa;">{{ addForm.fileName }}</a>
        </el-form-item>
      </el-form>
      <span slot="footer" class="dialog-footer" v-if="title == '检验'">
        <el-button @click="addDia = false">取 消</el-button>
        <el-button :loading="uploading" type="primary" @click="submitProduct('addForm')">确 认</el-button>
      </span>
    </el-dialog>
  </div>
</template>

<script>
import limsTable from "@/components/Table/lims-table.vue";
import { selectInspection, addOrUpdateInspection, delInspection, updateInspection } from '@/api/business/outsourcedParts.js'
export default {
  components: { limsTable },
  data() {
    return {
      queryParams: {},
      tableData: [],
      value: '',
      column: [
        { label: "委托编号", prop: "entrustmentNo" },
        { label: "产品", prop: "name" },
        { label: "来料数量", prop: "num" },
        {
          label: "供货厂家",
          prop: "supplier"
        },
        { label: "订单号", prop: "orderNum" },
        { label: "SP号", prop: "spNum" },
        {
          label: "检验状态", prop: "inspectionStatus", dataType: 'tag',
          formatData: (params) => {
            let obj = this.inspectionTaskState.find(m => m.value == params)
            if (obj) {
              return obj.label
            } else {
              return ''
            }
          },
          formatType: (params) => {
            if (params == 0) {
              return 'danger'
            } else {
              return 'success'
            }
          }
        },
        { label: "备注", prop: "remark" },
        {
          dataType: "action",
          label: "操作",
          operation: [
            // {
            //   name: "编辑",
            //   type: "text",
            //   clickFun: (row) => {
            //     this.openAdd("编辑", row);
            //   },
            // },
            // {
            //   name: "删除",
            //   type: "text",
            //   clickFun: (row) => {
            //     this.handleDelete(row);
            //   },
            //   disabled: (row) => {
            //     return !!row.ratifyUser
            //   },
            // },
            {
              name: "检验",
              type: "text",
              clickFun: (row) => {
                this.openAdd('检验', row);
              },
              disabled: (row) => {
                return row.inspectionStatus > 0
              },
            },
            {
              name: "查看",
              type: "text",
              clickFun: (row) => {
                this.openAdd('查看', row);
              },
            },
          ],
        },
      ],
      page: {
        total: 0,
        size: 20,
        current: 0,
      },
      tableLoading: false,
      title: "新增",
      addDia: false,
      addForm: {},
      addRules: {
        name: [{ required: true, message: "请输入产品名称", trigger: "blur" }],
        num: [
          { required: true, message: "请输入来料数量", trigger: "blur" },
        ],
        supplier: [
          { required: true, message: "请输入供货厂家", trigger: "blur" },
        ],
        orderNum: [{ required: true, message: "请输入订单号", trigger: "blur" }],
        spNum: [
          { required: true, message: "请输入SP号", trigger: "blur" },
        ],
        inspectionItems: [
          { required: true, message: "请输入外观", trigger: "blur" },
        ],
        result: [
          { required: true, message: "请选择检测结果", trigger: "change" },
        ],
      },
      uploading: false,
      inspectionTaskState: []
    }
  },
  mounted() {
    this.getDicts("inspection_task_state").then((response) => {
      this.inspectionTaskState = this.dictToValue(response.data);
    });
    this.getList()
  },
  methods: {
    getList() {
      this.tableLoading = true;
      let param = { ...this.queryParams, ...this.page };
      delete param.total;
      selectInspection({ ...param })
        .then((res) => {
          this.tableLoading = false;
          if (res.code === 200) {
            this.tableData = res.data.records;
            this.page.total = res.data.total;
          }
        })
        .catch((err) => {
          this.tableLoading = false;
        });
    },
    pagination({ page, limit }) {
      this.page.current = page;
      this.page.size = limit;
      this.getList();
    },
    refresh() {
      this.queryParams = {};
      this.page.current = 1;
      this.getList();
    },
    refreshTable() {
      this.page.current = 1;
      this.getList();
    },
    // 新增/编辑/检验
    openAdd(title, row) {
      this.title = title;
      this.file = null;
      if (row) {
        this.addForm = row;
      } else {
        this.addForm = {};
      }
      this.addDia = true;
    },
    // 新增/编辑/检验--提交
    submitProduct(formName) {
      this.$refs[formName].validate((valid) => {
        if (valid) {
          this.uploading = true;
          if (this.title == "新增" || this.title == "编辑") {
            addOrUpdateInspection(this.addForm)
              .then((res) => {
                this.uploading = false;
                if (res.code != 200) {
                  return;
                }
                this.$message.success("提交成功");
                this.refresh();
                this.addDia = false;
              })
              .catch((err) => {
                this.uploading = false;
              });
          } else {
            // 检验
            let fd = new FormData();
            //文件信息中raw才是真的文件
            if (this.addForm.file) {
              fd.append("file", this.addForm.file.raw);
            }
            fd.append("inspectionItems", this.addForm.inspectionItems);
            fd.append("result", this.addForm.result);
            fd.append("id", this.addForm.id);  // 添加id参数
            updateInspection(fd)
              .then(res => {
                this.uploading = false;
                if (res.code === 200) {
                  this.$message.success("检验提交成功");
                  this.refresh();
                  this.addDia = false;
                }
              })
              .catch(err => {
                this.uploading = false;
              });
          }
        } else {
          return false;
        }
      });
    },
    // 删除
    handleDelete(row) {
      this.$confirm("是否删除该条数据?", "提示", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      })
        .then(() => {
          delInspection({ id: row.id }).then((res) => {
            if (res.code == 200) {
              this.$message.success("删除成功");
              this.refresh();
            }
          });
        })
        .catch(() => { });
    },
    handleChangeUpload(file, fileLists) {
      this.addForm.file = file
    },
    // 下载附件的文件
    handleDown(row) {
      this.$download.saveAs(row.fileUrl, row.fileName);
    },
  }
}
</script>

<style scoped>
.search {
  display: flex;
  justify-content: space-between;
  align-items: center;
}
</style>